@@ -3,7 +3,7 @@
  *
  * Used in conjunction with the libxlsxwriter library.
  *
- * Copyright 2014-2017, John McNamara, jmcnamara@cpan.org. See LICENSE.txt.
+ * Copyright 2014-2018, John McNamara, jmcnamara@cpan.org. See LICENSE.txt.
  *
  */
 
@@ -38,7 +38,6 @@ STATIC lxw_error _add_file_to_zip(lxw_packager *self, FILE * file,
 
 #include <windows.h>
 
-
 #ifdef USE_SYSTEM_MINIZIP
 #include "minizip/iowin32.h"
 #else
@@ -63,7 +62,7 @@ _open_zipfile_win32(const char *filename)
     }
 
     /* Use the native Win32 file handling functions with minizip. */
-    fill_win32_filefunc64(&filefunc);
+    fill_win32_filefunc64W(&filefunc);
 
     return zipOpen2_64(wide_filename, 0, NULL, &filefunc);
 }
@@ -227,9 +226,9 @@ _write_image_files(lxw_packager *self)
             }
 
             err = _add_file_to_zip(self, image_stream, filename);
-            RETURN_ON_ERROR(err);
-
             fclose(image_stream);
+
+            RETURN_ON_ERROR(err);
         }
     }
 
